package migrations

import migrate "github.com/rubenv/sql-migrate"

func init() {
	m := &Migration{
		Migration: &migrate.Migration{
			Id: "20210503152056_create_manifest_references_table",
			Up: []string{
				`CREATE TABLE IF NOT EXISTS manifest_references (
					id bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
					top_level_namespace_id bigint NOT NULL,
					repository_id bigint NOT NULL,
					parent_id bigint NOT NULL,
					child_id bigint NOT NULL,
					created_at timestamp WITH time zone NOT NULL DEFAULT now(),
					CONSTRAINT pk_manifest_references PRIMARY KEY (top_level_namespace_id, repository_id, id),
					CONSTRAINT fk_manifest_references_tp_lvl_nmspc_id_rpsty_id_prnt_id_mnfsts FOREIGN KEY (top_level_namespace_id, repository_id, parent_id) REFERENCES manifests (top_level_namespace_id, repository_id, id) ON DELETE CASCADE,
					CONSTRAINT fk_manifest_references_tp_lvl_nmspc_id_rpsty_id_chld_id_mnfsts FOREIGN KEY (top_level_namespace_id, repository_id, child_id) REFERENCES manifests (top_level_namespace_id, repository_id, id),
					CONSTRAINT unique_manifest_references_tp_lvl_nmspc_id_rpy_id_prt_id_chd_id UNIQUE (top_level_namespace_id, repository_id, parent_id, child_id),
					CONSTRAINT check_manifest_references_parent_id_and_child_id_differ CHECK (parent_id <> child_id)
				)
				PARTITION BY HASH (top_level_namespace_id)`,
				"CREATE INDEX IF NOT EXISTS index_manifest_references_on_tp_lvl_nmspc_id_rpstry_id_chld_id ON manifest_references USING btree (top_level_namespace_id, repository_id, child_id)",
			},
			Down: []string{
				"DROP INDEX IF EXISTS index_manifest_references_on_tp_lvl_nmspc_id_rpstry_id_chld_id CASCADE",
				"DROP TABLE IF EXISTS manifest_references CASCADE",
			},
		},
		PostDeployment: false,
	}

	allMigrations = append(allMigrations, m)
}
