package migrations

import migrate "github.com/rubenv/sql-migrate"

func init() {
	m := &Migration{
		Migration: &migrate.Migration{
			Id: "20210503152740_create_gc_blobs_layers_table",
			Up: []string{
				`CREATE TABLE IF NOT EXISTS gc_blobs_layers (
					id bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
					top_level_namespace_id bigint NOT NULL,
					repository_id bigint NOT NULL,
					layer_id bigint NOT NULL,
					digest bytea NOT NULL,
					CONSTRAINT pk_gc_blobs_layers PRIMARY KEY (digest, id),
					CONSTRAINT fk_gc_blobs_layers_top_lvl_nmspc_id_rptry_id_lyr_id_dgst_layers FOREIGN KEY (top_level_namespace_id, repository_id, layer_id, digest) REFERENCES layers (top_level_namespace_id, repository_id, id, digest) ON DELETE CASCADE,
					CONSTRAINT fk_gc_blobs_layers_digest_blobs FOREIGN KEY (digest) REFERENCES blobs (digest) ON DELETE CASCADE,
					CONSTRAINT unique_gc_blobs_layers_digest_and_layer_id UNIQUE (digest, layer_id)
				)
				PARTITION BY HASH (digest)`,
				"CREATE INDEX IF NOT EXISTS index_gc_blobs_layers_on_top_lvl_nmspc_id_rpstry_id_lyr_id_dgst ON gc_blobs_layers USING btree (top_level_namespace_id, repository_id, layer_id, digest)",
			},
			Down: []string{
				"DROP INDEX IF EXISTS index_gc_blobs_layers_on_top_lvl_nmspc_id_rpstry_id_lyr_id_dgst CASCADE",
				"DROP TABLE IF EXISTS gc_blobs_layers CASCADE",
			},
		},
		PostDeployment: false,
	}

	allMigrations = append(allMigrations, m)
}
