package migrations

import migrate "github.com/rubenv/sql-migrate"

func init() {
	m := &Migration{
		Migration: &migrate.Migration{
			Id: "20210503152927_create_gc_blobs_configurations_table",
			Up: []string{
				`CREATE TABLE IF NOT EXISTS gc_blobs_configurations (
					id bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
					top_level_namespace_id bigint NOT NULL,
					repository_id bigint NOT NULL,
					manifest_id bigint NOT NULL,
					digest bytea NOT NULL,
					CONSTRAINT pk_gc_blobs_configurations PRIMARY KEY (digest, id),
					CONSTRAINT fk_gc_blobs_configurations_tp_lvl_nspc_id_r_id_m_id_dgst_mnfsts FOREIGN KEY (top_level_namespace_id, repository_id, manifest_id, digest) REFERENCES manifests (top_level_namespace_id, repository_id, id, configuration_blob_digest) ON DELETE CASCADE,
					CONSTRAINT fk_gc_blobs_configurations_digest_blobs FOREIGN KEY (digest) REFERENCES blobs (digest) ON DELETE CASCADE,
					CONSTRAINT unique_gc_blobs_configurations_digest_and_manifest_id UNIQUE (digest, manifest_id)
				)
				PARTITION BY HASH (digest)`,
				"CREATE INDEX IF NOT EXISTS index_gc_blobs_configurations_on_tp_lvl_nmspc_id_r_id_m_id_dgst ON gc_blobs_configurations USING btree (top_level_namespace_id, repository_id, manifest_id, digest)",
			},
			Down: []string{
				"DROP INDEX IF EXISTS index_gc_blobs_configurations_on_tp_lvl_nmspc_id_r_id_m_id_dgst CASCADE",
				"DROP TABLE IF EXISTS gc_blobs_configurations CASCADE",
			},
		},
		PostDeployment: false,
	}

	allMigrations = append(allMigrations, m)
}
